from distutils.core import setup

setup(
	name			=	'abofly',
	version		=	'1.3.0',
	py_modules	=	['nester'],
	author		=	'chonti',
	author_email	=	'chonti@naver.com',
	description	=	'A simple printer of nested lists',
	)
